==> nextcloud-24.0.12.tgz: nextcloud/apps/workflowengine/l10n/pt_PT.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "O operador em questão é inválido",
    "The given regular expression is invalid" : "A dada expressão regular é inválida",
    "The given file size is invalid" : "O tamanho dado do ficheiro é inválido",
    "The given tag id is invalid" : "A determinada identificação da etiqueta é inválida",
    "The given IP range is invalid" : "O intervalo de IP dado é inválido",
    "The given IP range is not valid for IPv4" : "A gama IP dada não é válida para IPv4",
    "The given IP range is not valid for IPv6" : "A gama de IP indicada não é válida para IPv6",
    "The given time span is invalid" : "O período de tempo dado é inválido",
    "The given start time is invalid" : "A determinada hora de início é inválida",
    "The given end time is invalid" : "O tempo final dado é inválido",
    "The given group does not exist" : "O grupo em questão não existe",
    "File" : "Ficheiro",
    "File created" : "Ficheiro criado",
    "File updated" : "Ficheiro enviado",
    "File renamed" : "Ficheiro renomeado",
    "File deleted" : "Ficheiro apagado",
    "File accessed" : "Ficheiro acedido",
    "File copied" : "Ficheiro copiado",
    "Tag assigned" : "Etiqueta atribuída",
    "Someone" : "Alguém",
    "%s created %s" : "1%s criado 1%s",
    "%s modified %s" : "1%s modificado 1%s",
    "%s deleted %s" : "1%s apagado 1%s",
    "%s accessed %s" : "1%s acedido 1%s",
    "%s renamed %s" : "1%s renomeado 1%s",
    "%s copied %s" : "1%s copiado 1%s",
    "%s assigned %s to %s" : "1%s atribuido 1%s para 1%s",
    "Operation #%s does not exist" : "Operação #1%s não existe",
    "Entity %s does not exist" : "Entidade %s não existe",
    "Entity %s is invalid" : "Entidade %s é inválida",
    "No events are chosen." : "Não são escolhidos eventos.",
    "Entity %s has no event %s" : "Entidade %s não tem evento %s",
    "Check %s is invalid or does not exist" : "Verifique%sé inválido ou não existe",
    "Flow" : "Fluxo",
    "Nextcloud workflow engine" : "Motor de fluxo de trabalho da Nextcloud",
    "Select a filter" : "Selecionar um filtro",
    "Select a comparator" : "Selecionar um comparador",
    "Folder" : "Pasta",
    "Images" : "Imagens",
    "Predefined URLs" : "URLs Predefinidos",
    "Files WebDAV" : "Ficheiros WebDAV",
    "Android client" : "Cliente de Android",
    "iOS client" : "Cliente de iOS",
    "Desktop client" : "Cliente de PC",
    "Thunderbird & Outlook addons" : "Extras do Thunderbird & Outlook",
    "Cancel" : "Cancelar",
    "Delete" : "Apagar",
    "Save" : "Guardar",
    "matches" : "corresponde",
    "does not match" : "não corresponde",
    "is" : "é",
    "is not" : "não é",
    "File name" : "Nome do ficheiro",
    "File MIME type" : "Tipo de ficheiro MIME",
    "File size (upload)" : "Tamanho do ficheiro (envio)",
    "less" : "menor",
    "less or equals" : "menor ou igual",
    "greater or equals" : "maior ou igual",
    "greater" : "maior",
    "Request remote address" : "Solicitar endereço remoto",
    "matches IPv4" : "corresponde a IPv4",
    "does not match IPv4" : "não corresponde a IPv4",
    "matches IPv6" : "corresponde a IPv6",
    "does not match IPv6" : "não corresponde a IPv6",
    "File system tag" : "Etiqueta do sistema de ficheiros",
    "is tagged with" : "tem a etiqueta",
    "is not tagged with" : "não tem a etiqueta",
    "Request URL" : "Solicitar URL",
    "Request time" : "Tempo do pedido",
    "between" : "entre",
    "not between" : "fora de",
    "Request user agent" : "Solicitar agente de utilizador",
    "is member of" : "é membro de",
    "is not member of" : "não é um membro de",
    "No results" : "Sem resultados",
    "%s (invisible)" : "%s (invisível)",
    "%s (restricted)" : "%s (limitado)"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-25.0.7.tgz: nextcloud/apps/workflowengine/l10n/pt_PT.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "O operador em questão é inválido",
    "The given regular expression is invalid" : "A dada expressão regular é inválida",
    "The given file size is invalid" : "O tamanho dado do ficheiro é inválido",
    "The given tag id is invalid" : "A determinada identificação da etiqueta é inválida",
    "The given IP range is invalid" : "O intervalo de IP dado é inválido",
    "The given IP range is not valid for IPv4" : "A gama IP dada não é válida para IPv4",
    "The given IP range is not valid for IPv6" : "A gama de IP indicada não é válida para IPv6",
    "The given time span is invalid" : "O período de tempo dado é inválido",
    "The given start time is invalid" : "A determinada hora de início é inválida",
    "The given end time is invalid" : "O tempo final dado é inválido",
    "The given group does not exist" : "O grupo em questão não existe",
    "File" : "Ficheiro",
    "File created" : "Ficheiro criado",
    "File updated" : "Ficheiro enviado",
    "File renamed" : "Ficheiro renomeado",
    "File deleted" : "Ficheiro apagado",
    "File accessed" : "Ficheiro acedido",
    "File copied" : "Ficheiro copiado",
    "Tag assigned" : "Etiqueta atribuída",
    "Someone" : "Alguém",
    "%s created %s" : "1%s criado 1%s",
    "%s modified %s" : "1%s modificado 1%s",
    "%s deleted %s" : "1%s apagado 1%s",
    "%s accessed %s" : "1%s acedido 1%s",
    "%s renamed %s" : "1%s renomeado 1%s",
    "%s copied %s" : "1%s copiado 1%s",
    "%s assigned %s to %s" : "1%s atribuido 1%s para 1%s",
    "Operation #%s does not exist" : "Operação #1%s não existe",
    "Entity %s does not exist" : "Entidade %s não existe",
    "Entity %s is invalid" : "Entidade %s é inválida",
    "No events are chosen." : "Não são escolhidos eventos.",
    "Entity %s has no event %s" : "Entidade %s não tem evento %s",
    "Operation %s is invalid" : "Operação %s é inválida",
    "Check %s does not exist" : "Validação %s não existe",
    "Check %s is invalid" : "Validação %s é inválida",
    "Check %s is invalid or does not exist" : "Verifique%sé inválido ou não existe",
    "Flow" : "Fluxo",
    "Nextcloud workflow engine" : "Motor de fluxo de trabalho da Nextcloud",
    "Select a filter" : "Selecionar um filtro",
    "Select a comparator" : "Selecionar um comparador",
    "Folder" : "Pasta",
    "Images" : "Imagens",
    "Files WebDAV" : "Ficheiros WebDAV",
    "Android client" : "Cliente de Android",
    "iOS client" : "Cliente de iOS",
    "Desktop client" : "Cliente de PC",
    "Thunderbird & Outlook addons" : "Extras do Thunderbird & Outlook",
    "Cancel" : "Cancelar",
    "Delete" : "Apagar",
    "Save" : "Guardar",
    "matches" : "corresponde",
    "does not match" : "não corresponde",
    "is" : "é",
    "is not" : "não é",
    "File name" : "Nome do ficheiro",
    "File MIME type" : "Tipo de ficheiro MIME",
    "File size (upload)" : "Tamanho do ficheiro (envio)",
    "less" : "menor",
    "less or equals" : "menor ou igual",
    "greater or equals" : "maior ou igual",
    "greater" : "maior",
    "Request remote address" : "Solicitar endereço remoto",
    "matches IPv4" : "corresponde a IPv4",
    "does not match IPv4" : "não corresponde a IPv4",
    "matches IPv6" : "corresponde a IPv6",
    "does not match IPv6" : "não corresponde a IPv6",
    "File system tag" : "Etiqueta do sistema de ficheiros",
    "is tagged with" : "tem a etiqueta",
    "is not tagged with" : "não tem a etiqueta",
    "Request URL" : "Solicitar URL",
    "Request time" : "Tempo do pedido",
    "between" : "entre",
    "not between" : "fora de",
    "Request user agent" : "Solicitar agente de utilizador",
    "User group membership" : "Grupos do utilizador",
    "is member of" : "é membro de",
    "is not member of" : "não é um membro de",
    "No results" : "Sem resultados",
    "%s (invisible)" : "%s (invisível)",
    "%s (restricted)" : "%s (limitado)",
    "Predefined URLs" : "URLs Predefinidos"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
